@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2003-2013 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2003-2022 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@ void Imidi::close_midi (void)
 void Imidi::proc_midi (void) 
 {
     snd_seq_event_t  *E;
-    int              c, f, m, n, p, t, v;
+    int              c, f, k, n, p, t, v;
 
     // Read and process MIDI commands from the ALSA port.
     // Events related to keyboard state are sent to the 
@@ -124,9 +124,8 @@ void Imidi::proc_midi (void)
     {
 	snd_seq_event_input(_handle, &E);
         c = E->data.note.channel;               
-        m = _midimap [c] & 127;        // Keyboard and hold bits
-//        d = (_midimap [c] >>  8) & 7;  // Division number if (f & 2)
-        f = (_midimap [c] >> 12) & 7;  // Control enabled if (f & 4)
+        k = _midimap [c] & 15;
+        f = _midimap [c] >> 12;
         t = E->type;
 
 	switch (t)
@@ -155,11 +154,11 @@ void Imidi::proc_midi (void)
 	        }
                 else if (n <= 96)
 	        {
-                    if (m)
+                    if (f & 1)
 		    {
 	                if (_qnote->write_avail () > 0)
 	                {
-	                    _qnote->write (0, (1 << 24) | ((n - 36) << 8) | m);
+	                    _qnote->write (0, (1 << 24) | ((n - 36) << 16) | k);
                             _qnote->write_commit (1);
 	                } 
 		    }
@@ -173,11 +172,11 @@ void Imidi::proc_midi (void)
 	        }
                 else if (n <= 96)
 	        {
-                    if (m)
+                    if (f & 1)
 		    {
 	                if (_qnote->write_avail () > 0)
 	                {
-	                    _qnote->write (0, ((n - 36) << 8) | m);
+	                    _qnote->write (0, (0 << 24) | ((n - 36) << 16) | k);
                             _qnote->write_commit (1);
 	                } 
 		    }
@@ -192,14 +191,14 @@ void Imidi::proc_midi (void)
 	    {
 	    case MIDICTL_HOLD:
 		// Hold pedal.
-		if (m & HOLD_MASK)
-		{
-		    v = (v > 63) ? 9 : 8;
-	            if (_qnote->write_avail () > 0)
-	            {
-	                _qnote->write (0, (v << 24) | (m << 16));
+                if (f & 1)
+                {
+                    c = (v > 63) ? 9 : 8;
+                    if (_qnote->write_avail () > 0)
+                    {
+                        _qnote->write (0, (c << 24) | k);
                         _qnote->write_commit (1);
-	            } 
+                    }
 		}
 		break;
 
@@ -210,7 +209,7 @@ void Imidi::proc_midi (void)
 		{
 	            if (_qnote->write_avail () > 0)
 	            {
-	                _qnote->write (0, (2 << 24) | ( ALL_MASK << 16) | ALL_MASK);
+	                _qnote->write (0, (2 << 24) | NKEYBD);
                         _qnote->write_commit (1);
 	            } 
 		}
@@ -219,11 +218,11 @@ void Imidi::proc_midi (void)
             case MIDICTL_ANOFF:
 		// All notes off, accepted on channels controlling
 		// a keyboard. Does not clear held notes. 
-		if (m)
+		if (f & 1)
 		{
 	            if (_qnote->write_avail () > 0)
 	            {
-	                _qnote->write (0, (2 << 24) | (m << 16) | m);
+	                _qnote->write (0, (2 << 24) | k);
                         _qnote->write_commit (1);
 	            } 
 		}
